summaryrefslogtreecommitdiffstats
path: root/kmail/searchwindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/searchwindow.h')
-rw-r--r--kmail/searchwindow.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/searchwindow.h b/kmail/searchwindow.h
index f8da35d7..6ea4adf8 100644
--- a/kmail/searchwindow.h
+++ b/kmail/searchwindow.h
@@ -73,13 +73,13 @@ class SearchWindow: public KDialogBase, virtual public KXMLGUIClient
public:
/**
* Creates a new search window.
* @param tqparent The tqparent widget.
* @param name The (widget) name of the dialog.
* @param curFolder The folder which will be pre-selected as the base folder
* of search operations.
* @param modal Whether the dialog is to be shown modal.
*/
- SearchWindow( KMMainWidget* tqparent, const char* name=0,
+ SearchWindow( KMMainWidget* parent, const char* name=0,
KMFolder *curFolder=0, bool modal=false );
virtual ~SearchWindow();
@@ -73,13 +73,13 @@ class SearchWindow: public KDialogBase, virtual public KXMLGUIClient
/**
* Creates a new search window.
- * @param tqparent The tqparent widget.
+ * @param parent The parent widget.
* @param name The (widget) name of the dialog.
* @param curFolder The folder which will be pre-selected as the base folder